@@ -30,11 +30,12 @@ from pyqtgraph import QtCore, QtGui
 import os
 import logging
 
+
 _formclass, _baseclass = uic.loadUiType(
     os.path.join(os.path.dirname(os.path.abspath(__file__)),
                  "ui", "ChannelGroupBox.ui"))
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class ChannelGroupBox(QtGui.QWidget):
@@ -95,7 +96,8 @@ class ChannelGroupBox(QtGui.QWidget):
 
         #: (:obj:`dict`) channellabels
         self.__channellabels = {}
-
+        #: (:obj:`bool`) connected flag
+        self.__connected = False
         self.__connectChannels()
         self.setNumberOfChannels(-1)
         self.__ui.rComboBox.currentIndexChanged.connect(
@@ -126,16 +128,11 @@ class ChannelGroupBox(QtGui.QWidget):
         else:
             self.__defaultchannel = channel
 
-    def changeView(self, showhistogram=None, showlevels=None,
-                   showadd=None):
+    def changeView(self, showlevels=None):
         """ shows or hides the histogram widget
 
-        :param showhistogram: if histogram should be shown
-        :type showhistogram: :obj:`bool`
         :param showlevels: if levels should be shown
         :type showlevels: :obj:`bool`
-        :param showadd: if additional histogram should be shown
-        :type showadd: :obj:`bool`
         """
         if showlevels is True and self.__levels is False:
             if self.__colors:
@@ -252,7 +249,8 @@ class ChannelGroupBox(QtGui.QWidget):
             self.__rindex = index
         else:
             self.__rindex = -1
-        self.channelChanged.emit()
+        if self.__connected:
+            self.channelChanged.emit()
 
     @QtCore.pyqtSlot(int)
     def _onGChannelChanged(self, index):
@@ -262,7 +260,8 @@ class ChannelGroupBox(QtGui.QWidget):
             self.__gindex = index
         else:
             self.__gindex = -1
-        self.channelChanged.emit()
+        if self.__connected:
+            self.channelChanged.emit()
 
     @QtCore.pyqtSlot(int)
     def _onBChannelChanged(self, index):
@@ -272,7 +271,8 @@ class ChannelGroupBox(QtGui.QWidget):
             self.__bindex = index
         else:
             self.__bindex = -1
-        self.channelChanged.emit()
+        if self.__connected:
+            self.channelChanged.emit()
 
     def updateChannelLabels(self, chlabels):
         """ update red channel
@@ -365,6 +365,26 @@ class ChannelGroupBox(QtGui.QWidget):
         """
         return self.__colorchannel
 
+    def channelLabel(self):
+        """ provides color channel label
+
+        :returns: color channel label
+        :rtype: :obj:`str`
+        """
+        channel = self.__colorchannel
+        if channel == -1 or self.__numberofchannels + 2 == channel:
+            label = ",".join([str(ch) for ch in self.rgbchannels()])
+        elif channel == -2 or self.__numberofchannels + 1 == channel:
+            label = 'mean'
+        elif channel == 0:
+            if self.__numberofchannels:
+                label = 'sum'
+            else:
+                label = ""
+        else:
+            label = str(channel - 1)
+        return label
+
     def __connectChannels(self):
         """ connects channel signals
         """
@@ -380,6 +400,7 @@ class ChannelGroupBox(QtGui.QWidget):
             self._lowerchannelpushed)
         self.__ui.higherchannelPushButton.clicked.connect(
             self._higherchannelpushed)
+        self.__connected = True
 
     def __disconnectChannels(self):
         """ connects channel signals
@@ -396,6 +417,7 @@ class ChannelGroupBox(QtGui.QWidget):
             self._lowerchannelpushed)
         self.__ui.higherchannelPushButton.clicked.disconnect(
             self._higherchannelpushed)
+        self.__connected = False
 
     def setNumberOfChannels(self, number):
         """ sets maximum number of color channel
@@ -488,3 +510,4 @@ class ChannelGroupBox(QtGui.QWidget):
             self.__ui.channelComboBox.setCurrentIndex(channel)
             self.setChannel(channel, True)
             self.__connectChannels()
+            self.channelChanged.emit()
