@@ -38,7 +38,7 @@ _formclass, _baseclass = uic.loadUiType(
     os.path.join(os.path.dirname(os.path.abspath(__file__)),
                  "ui", "ConfigDialog.ui"))
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class TableWidgetDragCheckBoxes(QtGui.QTableWidget):
@@ -119,14 +119,18 @@ class TableWidgetDragCheckBoxes(QtGui.QTableWidget):
         selected = []
         for ri, (name, checked) in enumerate(self.__checkboxdata):
             ridx = self.model().index(ri, 0)
-            self.__checkboxdata[ri][1] = bool(
-                self.model().data(ridx, QtCore.Qt.CheckStateRole))
-            name = str(
-                self.model().data(ridx, QtCore.Qt.DisplayRole))
+            chst = self.model().data(ridx, QtCore.Qt.CheckStateRole)
+            if hasattr(chst, "toBool"):
+                chst = chst.toBool()
+            self.__checkboxdata[ri][1] = bool(chst)
+            name = self.model().data(ridx, QtCore.Qt.DisplayRole)
+            if hasattr(name, "toString"):
+                name = name.toString()
+            name = str(name)
             self.__checkboxdata[ri][0] = self.__nameitems[name] \
                 if name in self.__nameitems else name
             if self.__checkboxdata[ri][1]:
-                selected.append(self.__checkboxdata[ri][0])
+                selected.append(str(self.__checkboxdata[ri][0]))
         if selected == available:
             selected = []
         return selected
@@ -214,8 +218,12 @@ class ConfigDialog(QtGui.QDialog):
         self.refreshrate = 0.2
         #: (:obj:`float`) tool refresh rate time is s
         self.toolrefreshtime = 0.02
-        #: (:obj:`int`) maximal number of images in memory buffer
+        #: (:obj:`float`) tool polling interval is s
+        self.toolpollinginterval = 1.0
+        #: (:obj:`str`) maximal number of images in memory buffer
         self.maxmbuffersize = "1000"
+        #: (:obj:`str`) float type for pixel intensity
+        self.floattype = "float"
         #: (:obj:`bool`) show color distribution histogram widget
         self.showhisto = True
         #: (:obj:`bool`) show color distribution additional histogram widget
@@ -226,6 +234,8 @@ class ConfigDialog(QtGui.QDialog):
         self.showhighvaluemask = False
         #: (:obj:`bool`) show statistics widget
         self.showstats = True
+        #: (:obj:`bool`) show image step widget
+        self.showsteps = True
         #: (:obj:`bool`) calculate variance
         self.calcvariance = False
         #: (:obj:`bool`) zero mask enabled
@@ -264,6 +274,8 @@ class ConfigDialog(QtGui.QDialog):
         self.keepcoords = False
         #: (:obj:`bool`) lazy image slider
         self.lazyimageslider = True
+        #: (:obj:`bool`) crosshair locker switched on
+        self.crosshairlocker = True
 
         #: (:obj:`str`) json hidra detector server list
         self.detservers = "[]"
@@ -291,12 +303,21 @@ class ConfigDialog(QtGui.QDialog):
         #: (:obj:`str`) JSON dictionary with {label: file tango attribute}
         #  for Tango Attribute source
         self.tangofileattrs = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: tina properties}
+        #  for Tine Property source
+        self.tineprops = '{}'
         #: (:obj:`str`) JSON dictionary with {label: dir tango attribute}
         #  for Tango Attribute source
         self.tangodirattrs = '{}'
         #: (:obj:`str`) JSON dictionary with {label: doocs property}
         #  for DOOCS Property source
         self.doocsprops = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: epics PV name}
+        #  for Epics PV source
+        self.epicspvnames = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: epics PV shape}
+        #  for Epics PV source
+        self.epicspvshapes = '{}'
         #: (:obj:`str`) JSON dictionary with {label: url}
         #  for HTTP responce source
         self.httpurls = '{}'
@@ -382,6 +403,8 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.rateDoubleSpinBox.setValue(self.refreshrate)
         self.__ui.nrsourcesSpinBox.setValue(self.nrsources)
         self.__ui.toolrefreshtimeDoubleSpinBox.setValue(self.toolrefreshtime)
+        self.__ui.pollingintervalDoubleSpinBox.setValue(
+            self.toolpollinginterval)
         self.__ui.aspectlockedCheckBox.setChecked(self.aspectlocked)
         self.__ui.downsampleCheckBox.setChecked(self.autodownsample)
         self.__ui.keepCoordsCheckBox.setChecked(self.keepcoords)
@@ -403,6 +426,7 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.showmaskCheckBox.setChecked(self.showmask)
         self.__ui.showmaskhighCheckBox.setChecked(self.showhighvaluemask)
         self.__ui.showstatsCheckBox.setChecked(self.showstats)
+        self.__ui.showstepsCheckBox.setChecked(self.showsteps)
         self.__ui.calcvarianceCheckBox.setChecked(self.calcvariance)
         self.__ui.showsubCheckBox.setChecked(self.showsub)
         self.__ui.showtransCheckBox.setChecked(self.showtrans)
@@ -421,7 +445,10 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.interruptCheckBox.setChecked(self.interruptonerror)
         self.__ui.dirtransLineEdit.setText(self.dirtrans)
         self.__ui.attrLineEdit.setText(self.tangoattrs)
+        self.__ui.tinepropLineEdit.setText(self.tineprops)
         self.__ui.doocspropLineEdit.setText(self.doocsprops)
+        self.__ui.pvnameLineEdit.setText(self.epicspvnames)
+        self.__ui.pvshapeLineEdit.setText(self.epicspvshapes)
         self.__ui.evattrLineEdit.setText(self.tangoevattrs)
         self.__ui.fileattrLineEdit.setText(self.tangofileattrs)
         self.__ui.dirattrLineEdit.setText(self.tangodirattrs)
@@ -434,6 +461,14 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.sendroisCheckBox.setChecked(self.sendrois)
         self.__ui.showallroisCheckBox.setChecked(self.showallrois)
         self.__ui.sourcedisplayCheckBox.setChecked(self.sourcedisplay)
+        self.__ui.crosshairCheckBox.setChecked(self.crosshairlocker)
+
+        if self.floattype not in ["float", "float32", "float64"]:
+            self.floattype = "float"
+        fid = self.__ui.floatComboBox.findText(self.floattype)
+        if fid < 0:
+            fid = 0
+        self.__ui.floatComboBox.setCurrentIndex(fid)
 
         self.__ui.urlsLineEdit.installEventFilter(self)
         self.__objtitles[repr(self.__ui.urlsLineEdit)] = \
@@ -464,7 +499,7 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.secautoportCheckBox.stateChanged.connect(
             self._updateSecPortLineEdit)
         self.__ui.plusroiPushButton.clicked.connect(
-            self._addROIColorWidget)
+            self._addROIColorWidgetClicked)
         self.__ui.minusroiPushButton.clicked.connect(
             self._removeROIColorWidget)
 
@@ -486,17 +521,13 @@ class ConfigDialog(QtGui.QDialog):
             "Insert Row &Above", QtGui.QDialogButtonBox.ActionRole)
         self.__ui.adddownPushButton = self.__ui.filterButtonBox.addButton(
             "Insert Row &Below", QtGui.QDialogButtonBox.ActionRole)
-        # self.__ui.editPushButton = self.__ui.filterButtonBox.addButton(
-        #     "&Edit", QtGui.QDialogButtonBox.ActionRole)
         self.__ui.removePushButton = self.__ui.filterButtonBox.addButton(
             "&Delete Row", QtGui.QDialogButtonBox.ActionRole)
         self.__populateTable(0)
         self.__ui.addupPushButton.clicked.connect(self.__addup)
         self.__ui.adddownPushButton.clicked.connect(self.__adddown)
-        # self.__ui.editPushButton.clicked.connect(self.__edit)
         self.__ui.filterTableWidget.itemChanged.connect(
             self.__tableItemChanged)
-        # self.__ui.filterTableWidget.itemDoubleClicked.connect(self.__edit)
         self.__ui.removePushButton.clicked.connect(self.__remove)
 
     def __updateRecord(self):
@@ -633,6 +664,11 @@ class ConfigDialog(QtGui.QDialog):
                 self._addROIColorWidget(tuple(color))
 
     @QtCore.pyqtSlot()
+    def _addROIColorWidgetClicked(self):
+        """ add ROIs colors widgets
+        """
+        self._addROIColorWidget()
+
     def _addROIColorWidget(self, color=None):
         """ add ROIs colors widgets
 
@@ -688,8 +724,11 @@ class ConfigDialog(QtGui.QDialog):
         self.nanmask = self.__ui.nanmaskCheckBox.isChecked()
         self.secautoport = self.__ui.secautoportCheckBox.isChecked()
         self.refreshrate = float(self.__ui.rateDoubleSpinBox.value())
+        self.floattype = str(self.__ui.floatComboBox.currentText())
         self.toolrefreshtime = float(
             self.__ui.toolrefreshtimeDoubleSpinBox.value())
+        self.toolpollinginterval = float(
+            self.__ui.pollingintervalDoubleSpinBox.value())
         self.nrsources = int(
             self.__ui.nrsourcesSpinBox.value())
         self.showsub = self.__ui.showsubCheckBox.isChecked()
@@ -705,6 +744,7 @@ class ConfigDialog(QtGui.QDialog):
         self.showmask = self.__ui.showmaskCheckBox.isChecked()
         self.showhighvaluemask = self.__ui.showmaskhighCheckBox.isChecked()
         self.showstats = self.__ui.showstatsCheckBox.isChecked()
+        self.showsteps = self.__ui.showstepsCheckBox.isChecked()
         self.calcvariance = self.__ui.calcvarianceCheckBox.isChecked()
         self.aspectlocked = self.__ui.aspectlockedCheckBox.isChecked()
         self.autodownsample = self.__ui.downsampleCheckBox.isChecked()
@@ -719,6 +759,7 @@ class ConfigDialog(QtGui.QDialog):
         self.showallrois = self.__ui.showallroisCheckBox.isChecked()
         self.sourcedisplay = self.__ui.sourcedisplayCheckBox.isChecked()
         self.defdetservers = self.__ui.defdetserversCheckBox.isChecked()
+        self.crosshairlocker = self.__ui.crosshairCheckBox.isChecked()
 
         try:
             dirtrans = str(self.__ui.dirtransLineEdit.text()).strip()
@@ -731,6 +772,7 @@ class ConfigDialog(QtGui.QDialog):
             self.__ui.tabWidget.setCurrentIndex(3)
             self.__ui.dirtransLineEdit.setFocus(True)
             return
+
         try:
             attr = str(self.__ui.attrLineEdit.text()).strip()
             mytr = json.loads(attr)
@@ -742,6 +784,18 @@ class ConfigDialog(QtGui.QDialog):
             self.__ui.tabWidget.setCurrentIndex(3)
             self.__ui.attrLineEdit.setFocus(True)
             return
+
+        try:
+            prop = str(self.__ui.tinepropLineEdit.text()).strip()
+            mytr = json.loads(prop)
+            if isinstance(mytr, dict):
+                self.tineprops = prop
+        except Exception as e:
+            logger.warning(str(e))
+            # print(str(e))
+            self.__ui.tabWidget.setCurrentIndex(3)
+            self.__ui.tinepropLineEdit.setFocus(True)
+            return
         try:
             prop = str(self.__ui.doocspropLineEdit.text()).strip()
             mytr = json.loads(prop)
@@ -764,6 +818,28 @@ class ConfigDialog(QtGui.QDialog):
             self.__ui.tabWidget.setCurrentIndex(3)
             self.__ui.evattrLineEdit.setFocus(True)
             return
+        try:
+            attr = str(self.__ui.pvnameLineEdit.text()).strip()
+            mytr = json.loads(attr)
+            if isinstance(mytr, dict):
+                self.epicspvnames = attr
+        except Exception as e:
+            logger.warning(str(e))
+            # print(str(e))
+            self.__ui.tabWidget.setCurrentIndex(3)
+            self.__ui.pvnameLineEdit.setFocus(True)
+            return
+        try:
+            attr = str(self.__ui.pvshapeLineEdit.text()).strip()
+            mytr = json.loads(attr)
+            if isinstance(mytr, dict):
+                self.epicspvshapes = attr
+        except Exception as e:
+            logger.warning(str(e))
+            # print(str(e))
+            self.__ui.tabWidget.setCurrentIndex(3)
+            self.__ui.pvshapeLineEdit.setFocus(True)
+            return
         try:
             fileattr = str(self.__ui.fileattrLineEdit.text()).strip()
             mytr = json.loads(fileattr)
