@@ -34,11 +34,10 @@ import time
 import logging
 from pyqtgraph.graphicsItems.ROI import ROI, LineROI, Handle
 
-
 _VMAJOR, _VMINOR, _VPATCH = _pg.__version__.split(".")[:3] \
     if _pg.__version__ else ("0", "9", "0")
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class HandleWithSignals(Handle):
@@ -91,7 +90,6 @@ class SimpleLineROI(LineROI):
         :param args: dictionary with ROI parameters
         :type args: :obj:`dict`<:obj:`str`, :obj:`any`>
         """
-
         pos1 = _pg.Point(pos1)
         pos2 = _pg.Point(pos2)
         d = pos2 - pos1
