@@ -65,7 +65,7 @@ _pg.graphicsItems.GradientEditorItem.Gradients['highcontrastclip'] = {
 __all__ = ['HistogramHLUTWidget']
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class HistogramHLUTWidget(_pg.widgets.GraphicsView.GraphicsView):
