@@ -40,7 +40,7 @@ _VMAJOR, _VMINOR, _VPATCH = _pg.__version__.split(".")[:3] \
     if _pg.__version__ else ("0", "9", "0")
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class SafeImageItem(_pg.ImageItem):
@@ -69,8 +69,10 @@ class SafeImageItem(_pg.ImageItem):
             _pg.ImageItem.paint(self, p, *args)
         except ValueError as e:
             logger.warning(str(e))
-            # print(str(e))
-            # print("Shape mismatch: skip painting")
+        except TypeError as e:
+            logger.warning(str(e))
+        except Exception as e:
+            logger.warning(str(e))
 
 
 class AxesParameters(object):
@@ -495,6 +497,13 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
                     img, lut=None,
                     # levels=[[0,255], [0, 255], [0, 255]],
                     autoLevels=False)
+            elif (self.__autodisplaylevels
+                  and self.__displaylevels[0] is not None
+                  and self.__displaylevels[1] is not None):
+                self.__image.setImage(
+                    img, autoLevels=False,
+                    levels=self.__displaylevels,
+                    autoDownsample=self.__autodownsample)
             elif (self.__autodisplaylevels
                   or self.__displaylevels[0] is None
                   or self.__displaylevels[1] is None):
