@@ -31,6 +31,9 @@ import json
 import struct
 import logging
 
+from . import dataFetchThread
+from .sardanaUtils import debugmethod
+
 try:
     import requests
     #: (:obj:`bool`) requests imported
@@ -71,6 +74,7 @@ try:
 except ImportError:
     #: (:obj:`bool`) PIL imported
     PILLOW = False
+
 try:
     import zmq
     #: (:obj:`str`,:obj:`str`) zmq major version, zmq minor version
@@ -79,6 +83,26 @@ except Exception:
     #: (:obj:`str`,:obj:`str`) zmq major version, zmq minor version
     ZMQMAJOR, ZMQMINOR = 0, 0
 
+try:
+    import epics
+    #: (:obj:`bool`) pyepics imported
+    PYEPICS = True
+except ImportError:
+    #: (:obj:`bool`) pyepics imported
+    PYEPICS = False
+
+try:
+    import PyTine
+    #: (:obj:`bool`) PyTine imported
+    PyTine.get
+    PYTINE = True
+except ImportError:
+    #: (:obj:`bool`) PyTine imported
+    PYTINE = False
+except AttributeError:
+    #: (:obj:`bool`) PyTine imported
+    PYTINE = False
+
 
 import socket
 import numpy as np
@@ -100,7 +124,7 @@ else:
     bytes = str
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 def tobytes(x):
@@ -139,6 +163,7 @@ class BaseSource(object):
 
     """ source base class"""
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -164,7 +189,7 @@ class BaseSource(object):
         """
         return {}
 
-    @QtCore.pyqtSlot(str)
+    @debugmethod
     def setConfiguration(self, configuration):
         """ set configuration
 
@@ -175,6 +200,7 @@ class BaseSource(object):
             self._configuration = configuration
             self._initiated = False
 
+    @debugmethod
     def setTimeOut(self, timeout):
         """ set timeout
 
@@ -183,6 +209,7 @@ class BaseSource(object):
         """
         self._timeout = timeout
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -199,6 +226,7 @@ class BaseSource(object):
             ]),
             '__random_%s__' % self.__counter, "")
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -206,6 +234,7 @@ class BaseSource(object):
         self.__counter = 0
         return True
 
+    @debugmethod
     def disconnect(self):
         """ disconnects the source
         """
@@ -214,6 +243,7 @@ class BaseSource(object):
         except Exception:
             pass
 
+    @debugmethod
     def _updaterror(self):
         """ updates error  message
         """
@@ -226,6 +256,7 @@ class FixTestSource(BaseSource):
     """ image source as Tango attributes describing
         an image file name and its directory"""
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -248,6 +279,7 @@ class FixTestSource(BaseSource):
                 for _ in range(self.__shape[1])
             ])
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -258,6 +290,7 @@ class FixTestSource(BaseSource):
         return (self.__image,
                 '__random_%s__' % self.__counter, "")
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -265,6 +298,7 @@ class FixTestSource(BaseSource):
         self.__counter = 0
         return True
 
+    @debugmethod
     def disconnect(self):
         """ disconnects the source
         """
@@ -279,6 +313,7 @@ class NXSFileSource(BaseSource):
     """ image source as Tango attributes describing
         an image file name and its directory"""
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -305,6 +340,7 @@ class NXSFileSource(BaseSource):
         #: (:obj:`bool`) nexus file source starts from the last image
         self.__nxslast = False
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -378,6 +414,7 @@ class NXSFileSource(BaseSource):
             pass  # this needs a bit more care
         return None, None, None
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -407,6 +444,7 @@ class NXSFileSource(BaseSource):
             self._updaterror()
             return False
 
+    @debugmethod
     def disconnect(self):
         """ disconnects the source
         """
@@ -419,6 +457,7 @@ class TangoFileSource(BaseSource):
     """ image source as Tango attributes describing
         an image file name and its directory"""
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -436,6 +475,7 @@ class TangoFileSource(BaseSource):
         #:      translation dictionary for the image directory
         self.__dirtrans = {"/ramdisk/": "/gpfs/"}
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -467,6 +507,7 @@ class TangoFileSource(BaseSource):
             pass  # this needs a bit more care
         return None, None, None
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -493,6 +534,7 @@ class VDEOdecoder(object):
     """ VIDEO IMAGE LIMA decoder
     """
 
+    @debugmethod
     def __init__(self):
         """ constructor
 
@@ -518,17 +560,21 @@ class VDEOdecoder(object):
         #: (:obj:`dict` <:obj:`int`, :obj:`str` > ) dtype modes
         self.__dtypeID = {0: 'uint8', 1: 'uint16', 2: 'uint32', 3: 'uint64'}
 
+    # @debugmethod
     def load(self, data):
         """  loads encoded data
 
         :param data: encoded data
         :type data: [:obj:`str`, :obj:`str`]
         """
+        logger.debug(
+            "lavuelib.imageSource.VDEOdecoder.load:  %s" % str(data[0]))
         self.__data = data
         self.format = data[0]
         self._loadHeader(data[1][:struct.calcsize(self.__headerFormat)])
         self.__value = None
 
+    @debugmethod
     def _loadHeader(self, headerData):
         """ loads the image header
 
@@ -549,6 +595,7 @@ class VDEOdecoder(object):
 
         self.dtype = self.__dtypeID[self.__header['imageMode']]
 
+    @debugmethod
     def shape(self):
         """ provides the data shape
 
@@ -556,8 +603,9 @@ class VDEOdecoder(object):
         :rtype: :obj:`list` <:obj:`int` >
         """
         if self.__header:
-            return [self.__header['width'], self.__header['height']]
+            return [self.__header['height'], self.__header['width']]
 
+    @debugmethod
     def frameNumber(self):
         """ provides the frame number
 
@@ -567,6 +615,7 @@ class VDEOdecoder(object):
         if 'frameNumber' in self.__header.keys():
             return self.__header['frameNumber']
 
+    @debugmethod
     def decode(self):
         """ provides the decoded data
 
@@ -581,8 +630,8 @@ class VDEOdecoder(object):
             fSize = struct.calcsize(dformat)
             self.__value = np.array(
                 struct.unpack(dformat * (len(image) // fSize), image),
-                dtype=self.dtype).reshape(self.__header['width'],
-                                          self.__header['height'])
+                dtype=self.dtype).reshape(self.__header['height'],
+                                          self.__header['width']).T
             fendian = self.__header['endianness']
             lendian = ord(struct.pack('=H', 1).decode()[-1])
             if fendian != lendian:
@@ -599,6 +648,7 @@ class TangoAttrSource(BaseSource):
     """ image source as IMAGE Tango attribute
     """
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -625,6 +675,7 @@ class TangoAttrSource(BaseSource):
         #: (:obj:`bool`) bytearray flag
         self.__bytearray = False
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -694,6 +745,7 @@ class TangoAttrSource(BaseSource):
             return str(e), "__ERROR__", ""
         return None, None, None
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -714,6 +766,7 @@ class TangoEventsCB(object):
 
     """ tango attribute callback class"""
 
+    @debugmethod
     def __init__(self, client, name, mutex):
         """ constructor
 
@@ -728,11 +781,18 @@ class TangoEventsCB(object):
         self.__name = name
         self.__mutex = mutex
 
-    def push_event(self, *args, **kwargs):
+    # @debugmethod
+    def push_event(self, event_data):
         """callback method receiving the event
         """
 
-        event_data = args[0]
+        if logger.getEffectiveLevel() >= 10:
+            trunk = str(event_data)
+            if len(trunk) > 1300:
+                trunk = trunk[:800] + " ... " + trunk[-500:]
+            logger.debug(
+                "lavuelib.imageSource.TangoEventCB.push_event: %s"
+                % trunk)
         if event_data.err:
             result = event_data.errors
             logger.warning(str(result))
@@ -748,11 +808,60 @@ class TangoEventsCB(object):
                         self.__client.reading = False
 
 
+class TangoReadyEventsCB(object):
+
+    """ tango attribute callback class"""
+
+    @debugmethod
+    def __init__(self, client, name, mutex):
+        """ constructor
+
+        :param client: tango controller client
+        :type client: :class:`str`
+        :param name: attribute name
+        :type name: :obj:`str`
+        :param mutex: mutex lock for CB
+        :type type: :class:`pyqtgraph.QtCore.QMutex`
+        """
+        self.__client = client
+        self.__name = name
+        self.__mutex = mutex
+
+    # @debugmethod
+    def push_event(self, event_data):
+        """callback method receiving the event
+        """
+
+        if logger.getEffectiveLevel() >= 10:
+            trunk = str(event_data)
+            if len(trunk) > 1300:
+                trunk = trunk[:800] + " ... " + trunk[-500:]
+            logger.debug(
+                "lavuelib.imageSource.TangoEventCB.push_event: %s"
+                % trunk)
+        if event_data.err:
+            result = event_data.errors
+            logger.warning(str(result))
+            # print(str(result))
+        else:
+            if not self.__client.reading:
+                with QtCore.QMutexLocker(self.__mutex):
+                    try:
+                        self.__client.reading = True
+                        _, attrnm = str(event_data.attr_name).rsplit("/", 1)
+                        self.__client.attr = event_data.device.read_attribute(
+                            attrnm)
+                        self.__client.fresh = True
+                    finally:
+                        self.__client.reading = False
+
+
 class TangoEventsSource(BaseSource):
 
     """ image source as IMAGE Tango attribute
     """
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -770,6 +879,7 @@ class TangoEventsSource(BaseSource):
         #:      device proxy for the image attribute
         self.__proxy = None
         self.__attrid = None
+        self.__rattrid = None
         self.attr = None
         #: (:dict: <:obj:`str`, :obj:`any`>)
         #:      dictionary of external decorders
@@ -785,6 +895,7 @@ class TangoEventsSource(BaseSource):
             "RGB24": "decode_rgb32"
         }
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -846,9 +957,9 @@ class TangoEventsSource(BaseSource):
             logger.warning(str(e))
             # print(str(e))
             return str(e), "__ERROR__", ""
-            pass  # this needs a bit more care
         return None, None, None
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -858,11 +969,26 @@ class TangoEventsSource(BaseSource):
                 # with QtCore.QMutexLocker(self.__mutex):
                 dvname, atname = str(self._configuration).rsplit('/', 1)
                 attr_cb = TangoEventsCB(self, atname, self.__mutex)
+                rattr_cb = TangoReadyEventsCB(self, atname, self.__mutex)
                 self.__proxy = PyTango.DeviceProxy(dvname)
-                self.__attrid = self.__proxy.subscribe_event(
-                    atname,
-                    PyTango.EventType.CHANGE_EVENT,
-                    attr_cb)
+                exc = ""
+                try:
+                    self.__attrid = self.__proxy.subscribe_event(
+                        atname,
+                        PyTango.EventType.CHANGE_EVENT,
+                        attr_cb)
+                except Exception as e:
+                    self.__attrid = None
+                    exc += str(e)
+                    try:
+                        self.__rattrid = self.__proxy.subscribe_event(
+                            atname,
+                            PyTango.EventType.DATA_READY_EVENT,
+                            rattr_cb)
+                    except Exception as e:
+                        self.__rattrid = None
+                        exc += str(e)
+                        raise Exception(exc)
                 self._initiated = True
             return True
         except Exception as e:
@@ -871,15 +997,22 @@ class TangoEventsSource(BaseSource):
             self._updaterror()
             return False
 
+    @debugmethod
     def disconnect(self):
         """ disconnects the source
         """
         try:
-            if not self._initiated:
+            if self._initiated:
                 with QtCore.QMutexLocker(self.__mutex):
                     self._initiated = False
-                    if self.__proxy is not None and self.__attrid is not None:
+                    proxy = self.__proxy
+                if proxy is not None:
+                    if self.__attrid is not None:
                         self.__proxy.unsubscribe_event(self.__attrid)
+                        self.__attrid = None
+                    if self.__rattrid is not None:
+                        self.__proxy.unsubscribe_event(self.__rattrid)
+                        self.__rattrid = None
         except Exception:
             self._updaterror()
 
@@ -889,6 +1022,7 @@ class HTTPSource(BaseSource):
     """ image source as HTTP request response
     """
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -901,6 +1035,7 @@ class HTTPSource(BaseSource):
         #: (:obj:`dict` <:obj:`str`, :obj:`any` > ) HTTP header data
         self.__header = {}
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -909,11 +1044,7 @@ class HTTPSource(BaseSource):
         """
         if self._configuration:
             try:
-                if self.__header:
-                    response = requests.get(
-                        self._configuration, headers=self.__header)
-                else:
-                    response = requests.get(self._configuration)
+                response = self.__get()
                 if response.ok:
                     name = self._configuration
                     data = response.content
@@ -953,15 +1084,44 @@ class HTTPSource(BaseSource):
                             return (np.transpose(img),
                                     "%s (%s)" % (name, time.ctime()), "")
                 else:
-                    # print("HTTP Source: %s" % str(response.content))
-                    logger.info("HTTP Source: %s" % str(response.content))
+                    logger.info(
+                        "HTTPSource.getData: %s" % str(response.content))
                     pass
             except Exception as e:
                 # print(str(e))
                 logger.warning(str(e))
                 return str(e), "__ERROR__", ""
+            else:
+                if str(response.text) == 'Image not available':
+                    return str(response.text), None, None
+                else:
+                    return str(response.text), "__ERROR__", None
         return "No url defined", "__ERROR__", None
 
+    # @debugmethod
+    def __get(self):
+        """ get response
+
+        :returns: response object
+        :rtype: :class:`requests.Response`
+        """
+        if self.__header:
+            try:
+                return requests.get(
+                    self._configuration, headers=self.__header,
+                    timeout=(self._timeout/1000. if self._timeout else None))
+            except AttributeError:
+                return requests.get(
+                    self._configuration, headers=self.__header)
+        else:
+            try:
+                return requests.get(
+                    self._configuration,
+                    timeout=(self._timeout/1000. if self._timeout else None))
+            except AttributeError:
+                return requests.get(self._configuration)
+
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -979,10 +1139,7 @@ class HTTPSource(BaseSource):
                             x * (100 ** i) for i, x in enumerate(lst))
                         if lversion >= 10800:
                             self.__header = {'Accept': 'application/tiff'}
-                if self.__header:
-                    requests.get(self._configuration, headers=self.__header)
-                else:
-                    requests.get(self._configuration)
+                self.__get()
             return True
         except Exception as e:
             logger.warning(str(e))
@@ -995,6 +1152,7 @@ class ZMQSource(BaseSource):
 
     """ image source as ZMQ stream"""
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -1016,7 +1174,7 @@ class ZMQSource(BaseSource):
         #: (:class:`pyqtgraph.QtCore.QMutex`) mutex lock for zmq source
         self.__mutex = QtCore.QMutex()
 
-    @QtCore.pyqtSlot(str)
+    @debugmethod
     def setConfiguration(self, configuration):
         """ set configuration
 
@@ -1042,6 +1200,7 @@ class ZMQSource(BaseSource):
                     self.__topic = tobytes(topic)
                     self.__socket.connect(self.__bindaddress)
 
+    @debugmethod
     def __loads(self, message, encoding=None):
         """ loads json or pickle string
 
@@ -1063,6 +1222,7 @@ class ZMQSource(BaseSource):
                 metadata = json.loads(smessage)
         return metadata
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -1163,6 +1323,7 @@ class ZMQSource(BaseSource):
             return str(e), "__ERROR__", ""
         return None, None, None
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -1198,6 +1359,7 @@ class ZMQSource(BaseSource):
             self._updaterror()
             return False
 
+    @debugmethod
     def disconnect(self):
         """ disconnects the source
         """
@@ -1226,6 +1388,7 @@ class HiDRASource(BaseSource):
 
     """ hidra image source"""
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -1252,7 +1415,7 @@ class HiDRASource(BaseSource):
         #: (:obj:`bool`) use tiff loader
         self.__tiffloader = False
 
-    @QtCore.pyqtSlot(str)
+    @debugmethod
     def setConfiguration(self, configuration):
         """ set configuration
 
@@ -1280,6 +1443,7 @@ class HiDRASource(BaseSource):
                 self.__query = None
             self._initiated = False
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
@@ -1292,7 +1456,8 @@ class HiDRASource(BaseSource):
             if not self._initiated:
                 with QtCore.QMutexLocker(self.__mutex):
                     # print("TARGET %s" % self.__target)
-                    logger.info("TARGET %s" % self.__target)
+                    logger.info(
+                        "HiDRASource.connect: TARGET %s" % self.__target)
                     self.__query.initiate(self.__target)
                 self._initiated = True
                 with QtCore.QMutexLocker(self.__mutex):
@@ -1307,6 +1472,7 @@ class HiDRASource(BaseSource):
             self._updaterror()
             return False
 
+    @debugmethod
     def disconnect(self):
         """ disconnects the source
         """
@@ -1314,9 +1480,11 @@ class HiDRASource(BaseSource):
             if self.__query is not None:
                 with QtCore.QMutexLocker(self.__mutex):
                     self.__query.stop()
+            self._initiated = False
         except Exception:
             self._updaterror()
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -1327,6 +1495,8 @@ class HiDRASource(BaseSource):
         data = None
         if self.__query is None:
             return "No server defined", "__ERROR__", None
+        if not self._initiated:
+            return None, None, None
         try:
             with QtCore.QMutexLocker(self.__mutex):
                 # [metadata, data] = self.__query.get()
@@ -1353,6 +1523,7 @@ class HiDRASource(BaseSource):
             if data[:10] == "###CBF: VE":
                 # print("[cbf source module]::metadata", metadata["filename"])
                 logger.info(
+                    "HiDRASource.getData: "
                     "[cbf source module]::metadata", metadata["filename"])
                 npdata = np.fromstring(data[:], dtype=np.uint8)
                 img = imageFileHandler.CBFLoader().load(npdata)
@@ -1365,6 +1536,7 @@ class HiDRASource(BaseSource):
             else:
                 # elif data[:2] in ["II\x2A\x00", "MM\x00\x2A"]:
                 logger.info(
+                    "HiDRASource.getData:"
                     "[tif source module]::metadata", metadata["filename"])
                 # print("[tif source module]::metadata", metadata["filename"])
                 if PILLOW and not self.__tiffloader:
@@ -1397,6 +1569,7 @@ class DOOCSPropSource(BaseSource):
     """ image source as IMAGE DOOCS property
     """
 
+    @debugmethod
     def __init__(self, timeout=None):
         """ constructor
 
@@ -1405,6 +1578,7 @@ class DOOCSPropSource(BaseSource):
         """
         BaseSource.__init__(self, timeout)
 
+    @debugmethod
     def getData(self):
         """ provides image name, image data and metadata
 
@@ -1427,7 +1601,219 @@ class DOOCSPropSource(BaseSource):
             return str(e), "__ERROR__", ""
         return None, None, None
 
+    @debugmethod
     def connect(self):
         """ connects the source
         """
         return True
+
+
+class EpicsPVSource(BaseSource):
+
+    """ image source as Epics Process variable"""
+
+    @debugmethod
+    def __init__(self, timeout=None):
+        """ constructor
+
+        :param timeout: timeout for setting connection in ms
+        :type timeout: :obj:`int`
+        """
+        BaseSource.__init__(self, timeout)
+        #: (:class:`epics.PV`)
+        #:       epics process variable
+        self.__pv = None
+        #: (:obj:`list` < :obj:`int` >)
+        #:      process variable shape
+        self.__shape = None
+        #: (:obj:`list` < :obj:`int` >)
+        #:      process variable size
+        self.__size = 0
+
+    @debugmethod
+    def getData(self):
+        """ provides image name, image data and metadata
+
+        :returns:  image name, image data, json dictionary with metadata
+        :rtype: (:obj:`str` , :class:`numpy.ndarray` , :obj:`str`)
+        """
+
+        if self.__pv is None:
+            return "No PV defined", "__ERROR__", None
+        try:
+            rawdata = self.__pv.get(as_numpy=True,
+                                    timeout=float(self._timeout/1000.))
+            if not hasattr(rawdata, "size"):
+                return None, None, None
+            else:
+                if self.__shape and rawdata.size >= self.__size:
+                    image = rawdata[:self.__size].reshape(self.__shape)
+                else:
+                    image = rawdata
+                return (np.transpose(image),
+                        '%s (%s)' % (self._configuration, time.time()), None)
+        except Exception as e:
+            logger.warning(str(e))
+            # print(str(e))
+            return str(e), "__ERROR__", ""
+            pass  # this needs a bit more care
+        return None, None, None
+
+    @debugmethod
+    def connect(self):
+        """ connects the source
+        """
+        try:
+            pvnm, pvsh = str(
+                self._configuration).strip().split(",", 1)
+            if not self._initiated:
+                self.__pv = epics.PV(pvnm)
+                try:
+                    shape = json.loads(pvsh)
+                    self.__shape = list(reversed([int(s) for s in shape]))
+                    self.__size = np.prod(self.__shape)
+                except Exception:
+                    self.__size = 0
+                    self.__shape = None
+            return True
+        except Exception as e:
+            self._updaterror()
+            logger.warning(str(e))
+            # print(str(e))
+            return False
+
+
+class TinePropSource(BaseSource):
+
+    """ image source as Tine Property """
+
+    @debugmethod
+    def __init__(self, timeout=None):
+        """ constructor
+
+        :param timeout: timeout for setting connection in ms
+        :type timeout: :obj:`int`
+        """
+        BaseSource.__init__(self, timeout)
+        #: (:obj:`str`)
+        #:       tine device address name
+        self.__address = None
+        #: (:obj:`str`)
+        #:       tine property name
+        self.__prop = None
+
+    @classmethod
+    def __dtype(cls, header):
+        """ provides dtype of tine property
+
+        :param header: tine frameHeader
+        :type header: :obj:`dict` <:obj:`str`, `any`>
+        :returns: numpy dtype
+        :rtype: :obj:`str`
+        """
+        dtype = ""
+        if not header or "bytesPerPixel" not in header:
+            raise ValueError("bytesPerPixel not defined in the header")
+
+        if header["bytesPerPixel"] == 1:
+            dtype = "u1"
+        elif header["bytesPerPixel"] == 2:
+            dtype = "u2"
+        else:
+            raise ValueError("Invalid bytesPerPixel: %s"
+                             % header["bytesPerPixel"])
+
+        return dtype
+
+    @classmethod
+    def __height(cls, header):
+        """ provides height of tine property
+
+        :param header: tine frameHeader
+        :type header: :obj:`dict` <:obj:`str`, `any`>
+        :returns: numpy dtype
+        :rtype: :obj:`str`
+        """
+        height = 0
+        if "aoiHeight" in header and header["aoiHeight"] > 0:
+            height = header["aoiHeight"]
+        elif "sourceHeight" in header:
+            height = header["sourceHeight"]
+
+        if not 0 < height <= 65535:
+            raise ValueError("Invalid height: %s" % height)
+
+        return height
+
+    @classmethod
+    def __width(cls, header):
+        """ provides width of tine property
+
+        :param header: tine frameHeader
+        :type header: :obj:`dict` <:obj:`str`, `any`>
+        :returns: numpy dtype
+        :rtype: :obj:`str`
+        """
+        width = 0
+        if "aoiWidth" in header and header["aoiWidth"] > 0:
+            width = header["aoiWidth"]
+        elif "sourceWidth" in header:
+            width = header["sourceWidth"]
+
+        if not 0 < width <= 65535:
+            raise ValueError("Invalid width: %s" % width)
+
+        return width
+
+    @debugmethod
+    def getData(self):
+        """ provides image name, image data and metadata
+
+        :returns:  image name, image data, json dictionary with metadata
+        :rtype: (:obj:`str` , :class:`numpy.ndarray` , :obj:`str`)
+        """
+
+        if not self.__address or not self.__prop:
+            return "No Tine Property defined", "__ERROR__", None
+        try:
+            interval = int(dataFetchThread.GLOBALREFRESHRATE*1000)
+            prop = PyTine.get(address=self.__address,
+                              property=self.__prop,
+                              timeout=interval)
+            rawdata = prop["data"]
+
+            if "imageMatrix" in rawdata:
+                image = rawdata["imageMatrix"]
+            else:
+                header = rawdata["frameHeader"]
+                dtype = self.__dtype(header)
+                height = self.__height(header)
+                width = self.__width(header)
+                image = np.frombuffer(rawdata["imageBytes"], dtype=dtype)
+                if len(image) != height * width:
+                    raise ValueError(
+                        "Dimension mismatch: size: %s != %s"
+                        % (len(image), height * width))
+                image = image.reshape((height, width))
+
+            timestamp = prop["timestamp"]
+            return (np.transpose(image),
+                    '%s (%s)' % (self._configuration, timestamp), None)
+        except Exception as e:
+            logger.warning(str(e))
+            # print(str(e))
+            return str(e), "__ERROR__", ""
+            pass  # this needs a bit more care
+        return None, None, None
+
+    @debugmethod
+    def setConfiguration(self, configuration):
+        """ set configuration
+
+        :param configuration:  configuration string
+        :type configuration: :obj:`str`
+        """
+        if self._configuration != configuration:
+            self._configuration = configuration
+            self.__address, self.__prop = str(
+                self._configuration).rsplit("/", 1)
