@@ -51,7 +51,7 @@ _formclass, _baseclass = uic.loadUiType(
     os.path.join(os.path.dirname(os.path.abspath(__file__)),
                  "ui", "ImageWidget.ui"))
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class ImageWidget(QtGui.QWidget):
@@ -537,7 +537,7 @@ class ImageWidget(QtGui.QWidget):
                 except Exception as e:
                     # print(str(e))
                     logger.warning(str(e))
-                self.__currenttool.disactivate()
+                self.__currenttool.deactivate()
 
     def updateMetaData(self, axisscales=None, axislabels=None,
                        rescale=False):
@@ -1118,7 +1118,7 @@ class ImageWidget(QtGui.QWidget):
                 _, warn = self.__sardana.runMacro(
                     str(self.__settings.doorname), command, wait=False)
                 if warn:
-                    logger.warning(str(warn))
+                    logger.warning("ImageWidget.runMacro %s" % str(warn))
                     # print("Warning: %s" % str(warn))
                     msg = str(warn)
                     messageBox.MessageBox.warning(
@@ -1356,7 +1356,7 @@ class ImageWidget(QtGui.QWidget):
                         text, str(value))
         else:
             # print("Connection error")
-            logger.error("Connection error")
+            logger.error("ImageWidget.applyROI: Connection error")
 
     @QtCore.pyqtSlot(str)
     def fetchROIs(self, rlabel):
@@ -1435,7 +1435,7 @@ class ImageWidget(QtGui.QWidget):
             self.updateROIs(len(coords), coords)
         else:
             # print("Connection error")
-            logger.error("Connection error")
+            logger.error("ImageWidget.fetchROIs: Connection error")
 
     def currentIntensity(self):
         """ provides intensity for current mouse position
@@ -1711,6 +1711,30 @@ class ImageWidget(QtGui.QWidget):
             self.mouseImagePositionChanged.emit()
             self.geometryChanged.emit()
 
+    @QtCore.pyqtSlot(float)
+    def updatePixelSizeX(self, x):
+        """ updates the pixel x-size
+
+        :param x: pixel x-size
+        :type x: :obj:`float`
+        """
+        if self.__settings.pixelsizex != x:
+            self.__settings.pixelsizex = x
+            self.mouseImagePositionChanged.emit()
+            self.geometryChanged.emit()
+
+    @QtCore.pyqtSlot(float)
+    def updatePixelSizeY(self, y):
+        """ updates the pixel y-size
+
+        :param y: pixel y-size
+        :type y: :obj:`float`
+        """
+        if self.__settings.pixelsizey != y:
+            self.__settings.pixelsizey = y
+            self.mouseImagePositionChanged.emit()
+            self.geometryChanged.emit()
+
     @QtCore.pyqtSlot(str)
     def updateDetectorROIs(self, rois):
         """ updates the detector ROIs
