@@ -31,6 +31,7 @@ from pyqtgraph import QtCore, QtGui
 from .histogramWidget import HistogramHLUTWidget
 from . import messageBox
 from . import gradientDialog
+
 # from .histogramWidget import HistogramHLUTItem
 import math
 import os
@@ -41,7 +42,7 @@ _formclass, _baseclass = uic.loadUiType(
                  "ui", "LevelsGroupBox.ui"))
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
 
 
 class LevelsGroupBox(QtGui.QWidget):
@@ -55,11 +56,13 @@ class LevelsGroupBox(QtGui.QWidget):
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) maximum level changed signal
     maxLevelChanged = QtCore.pyqtSignal(float)
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) automatic levels changed signal
-    autoLevelsChanged = QtCore.pyqtSignal(int)  # bool does not work...
+    autoLevelsChanged = QtCore.pyqtSignal(int)
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) levels changed signal
     levelsChanged = QtCore.pyqtSignal()
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) store settings requested
     storeSettingsRequested = QtCore.pyqtSignal()
+    #: (:class:`pyqtgraph.QtCore.pyqtSignal`) gradient changed signal
+    gradientChanged = QtCore.pyqtSignal()
 
     def __init__(self, parent=None, settings=None, expertmode=False):
         """ constructor
@@ -185,6 +188,11 @@ class LevelsGroupBox(QtGui.QWidget):
                     self.__histogram.region.setRegion([lowlim, uplim])
             finally:
                 self.__connectMinMax()
+        else:
+            lowlim = self.__ui.minDoubleSpinBox.value()
+            uplim = self.__ui.maxDoubleSpinBox.value()
+            self.minLevelChanged.emit(lowlim)
+            self.maxLevelChanged.emit(uplim)
 
     def changeView(self, showhistogram=None, showlevels=None,
                    showadd=None):
@@ -599,6 +607,7 @@ class LevelsGroupBox(QtGui.QWidget):
             self._updateGradient(0)
         else:
             logger.error(
+                "_removeGradientItem: "
                 "Error in _removeGradientItem for %s" % name)
             # print("Error %s" % name)
 
@@ -622,6 +631,7 @@ class LevelsGroupBox(QtGui.QWidget):
             index = self.__ui.gradientComboBox.findText(name)
         self.__histogram.setGradientByName(
             self.__ui.gradientComboBox.itemText(index))
+        self.gradientChanged.emit()
 
     @QtCore.pyqtSlot(str)
     def _changeGradient(self, name):
@@ -636,8 +646,11 @@ class LevelsGroupBox(QtGui.QWidget):
             if cid > -1:
                 self.__ui.gradientComboBox.setCurrentIndex(cid)
             else:
-                logger.error("Error in _changeGradient for %s" % name)
+                logger.error(
+                    "LevelsGroupBox.changeGradient: "
+                    "Error in _changeGradient for %s" % name)
                 # print("Error %s" % name)
+        self.gradientChanged.emit()
 
     def updateHistoImage(self, autoLevel=None):
         """ executes imageChanged of histogram with the givel autoLevel
