@@ -30,6 +30,7 @@ import json
 import time
 import sys
 import logging
+import functools
 
 try:
     import PyTango
@@ -42,13 +43,46 @@ except ImportError:
 if sys.version_info > (3,):
     basestring = str
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lavue")
+
+if sys.version_info > (3,):
+    unicode = str
+
+
+def debugmethod(method):
+    """ debug wrapper for methods
+    :param method: any class method
+    :type method: :class:`any`
+    :returns: wrapped class method
+    :rtype: :class:`any`
+    """
+    if logger.getEffectiveLevel() >= 10:
+        @functools.wraps(method)
+        def decmethod(*args, **kwargs):
+            name = "%s.%s.%s" % (
+                args[0].__class__.__module__,
+                args[0].__class__.__name__,
+                method.__name__
+            )
+            if args[1:]:
+                margs = " with %s " % str(args[1:])
+            else:
+                margs = ""
+            logger.debug("%s: excecuted %s" % (name, margs))
+            ret = method(*args, **kwargs)
+            logger.debug("%s: returns %s" % (
+                name, str(ret) if ret is not None else ''))
+            return ret
+        return decmethod
+    else:
+        return method
 
 
 class SardanaUtils(object):
 
     """ sardanamacro server"""
 
+    @debugmethod
     def __init__(self):
         """ constructor """
 
@@ -88,6 +122,7 @@ class SardanaUtils(object):
 
         return cnfServer
 
+    @debugmethod
     def getMacroServer(self, door):
         """ door macro server device name
 
@@ -98,18 +133,24 @@ class SardanaUtils(object):
         """
         if not door:
             raise Exception("Door '%s' cannot be found" % door)
+        logger.debug("SardanaUtils.getMacroServer: Door = %s" % door)
         sdoor = door.split("/")
         tangohost = None
         if len(sdoor) > 1 and ":" in sdoor[0]:
             door = "/".join(sdoor[1:])
             tangohost = sdoor[0]
+        logger.debug(
+            "SardanaUtils.getMacroServer: Tango Host = %s" % tangohost)
         if tangohost or not self.__db:
             host, port = tangohost.split(":")
             db = PyTango.Database(host, int(port))
         else:
             db = self.__db
+        logger.debug("SardanaUtils.getMacroServer: Database = %s" % str(db))
 
         servers = db.get_device_exported_for_class("MacroServer").value_string
+        logger.debug(
+            "SardanaUtils.getMacroServer: MacroSevers = %s" % str(servers))
         ms = None
 
         for server in servers:
@@ -121,17 +162,36 @@ class SardanaUtils(object):
             try:
                 dp = self.openProxy(msname)
             except Exception as e:
-                logger.warning(str(e))
+                logger.warning("SardanaUtils.getMacroServer: %s" % str(e))
                 # print(str(e))
                 dp = None
-            if hasattr(dp, "DoorList"):
-                lst = dp.DoorList
-                if lst and (door in lst or
-                            ("%s/%s" % (tangohost, door) in lst)):
+            if hasattr(dp, "DoorList") and dp.DoorList:
+                lst = [str(dr).lower() for dr in dp.DoorList]
+                logger.debug(
+                    "SardanaUtils.getMacroServer: DoorList = %s" % str(lst))
+                if lst and (door.lower() in lst or
+                            ("%s/%s" % (tangohost, door.lower()) in lst)):
                     ms = dp
+                    logger.debug(
+                        "SardanaUtils.getMacroServer: "
+                        "Door MacroServer = %s" % str(ms))
                     break
         return ms
 
+    @classmethod
+    def pickleloads(cls, bytestr):
+        """ loads pickle byte string
+        :param bytestr: byte string to convert
+        :type bytesstr: :obj:`bytes`
+        :returns: loaded bytestring
+        :rtype: :obj:`any`
+        """
+        if sys.version_info > (3,):
+            return pickle.loads(bytestr, encoding='latin1')
+        else:
+            return pickle.loads(bytestr)
+
+    @debugmethod
     def getScanEnv(self, door, params=None):
         """ fetches Scan Environment Data
 
@@ -145,13 +205,14 @@ class SardanaUtils(object):
         msp = self.getMacroServer(door)
         rec = msp.Environment
         if rec[0] == 'pickle':
-            dc = pickle.loads(rec[1])
+            dc = self.pickleloads(rec[1])
             if 'new' in dc.keys():
                 for var in params:
                     if var in dc['new'].keys():
                         res[var] = dc['new'][var]
         return json.dumps(res)
 
+    @debugmethod
     def getDeviceName(self, cname, db=None):
         """ finds device of give class
 
@@ -179,6 +240,7 @@ class SardanaUtils(object):
                 pass
         return device
 
+    @debugmethod
     def setScanEnv(self, door, jdata):
         """ stores Scan Environment Data
 
@@ -189,15 +251,34 @@ class SardanaUtils(object):
         """
         data = json.loads(jdata)
         msp = self.getMacroServer(door)
-        rec = msp.Environment
-        if rec[0] == 'pickle':
-            dc = pickle.loads(rec[1])
-            if 'new' in dc.keys():
-                for var in data.keys():
-                    dc['new'][str(var)] = self.toString(data[var])
-                pk = pickle.dumps(dc)
-                msp.Environment = ['pickle', pk]
+        dc = {'new': {}}
+        for var in data.keys():
+            dc['new'][str(var)] = self.toString(data[var])
+        try:
+            pk = pickle.dumps(dc, protocol=2)
+            msp.Environment = ['pickle', pk]
+        except Exception:
+            if sys.version_info < (3,):
+                raise
+            if isinstance(data, dict):
+                newvalue = {}
+                for key, vl in dc.items():
+                    if isinstance(vl, dict):
+                        nvl = {}
+                        for ky, it in vl.items():
+                            nvl[bytes(ky, "utf8")
+                                if isinstance(ky, unicode) else ky] = it
+                        newvalue[bytes(key, "utf8")
+                                 if isinstance(key, unicode) else key] = nvl
+                    else:
+                        newvalue[bytes(key, "utf8")
+                                 if isinstance(key, unicode) else key] = vl
+            else:
+                newvalue = dc
+            pk = pickle.dumps(newvalue, protocol=2)
+            msp.Environment = ['pickle', pk]
 
+    @debugmethod
     def wait(self, name=None, proxy=None, maxcount=100):
         """ stores Scan Environment Data
 
@@ -215,6 +296,7 @@ class SardanaUtils(object):
                 break
             time.sleep(0.01)
 
+    @debugmethod
     def runMacro(self, door, command, wait=True):
         """ stores Scan Environment Data
 
@@ -257,6 +339,7 @@ class SardanaUtils(object):
         else:
             return None, None
 
+    @debugmethod
     def getError(self, door):
         """ stores Scan Environment Data
 
@@ -289,6 +372,7 @@ class SardanaUtils(object):
         else:
             return obj
 
+    @debugmethod
     def getElementNames(self, door, listattr, typefilter=None):
         """ provides experimental Channels
 
@@ -320,6 +404,7 @@ class SardanaUtils(object):
                     elements.append(chan['name'])
         return elements
 
+    @debugmethod
     def getPools(self, door):
         """ provides pool devices
 
