@@ -57,10 +57,12 @@ class Settings(object):
         self.showaddhisto = False
         #: (:obj:`bool`) show mask widget
         self.showmask = False
-        #: (:obj:`bool`) show mask widget
+        #: (:obj:`bool`) show high mask value  widget
         self.showhighvaluemask = False
-        #: (:obj:`bool`) show mask widget
+        #: (:obj:`bool`) show statistics widget
         self.showstats = True
+        #: (:obj:`bool`) show image step widget
+        self.showsteps = True
         #: (:obj:`bool`) calculate variance
         self.calcvariance = False
         #: (:obj:`bool`) show bakcground subtraction widget
@@ -113,6 +115,8 @@ class Settings(object):
         self.refreshrate = 0.2
         #: (:obj:`float`) tool refresh rate time is s
         self.toolrefreshtime = 0.02
+        #: (:obj:`float`) tool polling interval is s
+        self.toolpollinginterval = 1.0
         #: (:obj:`bool`) interrupt on error
         self.interruptonerror = True
         #: (:obj:`str`) last image file name
@@ -132,6 +136,18 @@ class Settings(object):
         #: (:obj:`str`) JSON dictionary with {label: tango attribute}
         #  for Tango Attribute source
         self.tangoattrs = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: tango detector attribute}
+        #  for Tango Attribute source
+        self.tangodetattrs = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: tina properties}
+        #  for Tine Property source
+        self.tineprops = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: epics PV name}
+        #  for Epics PV source
+        self.epicspvnames = '{}'
+        #: (:obj:`str`) JSON dictionary with {label: epics PV shape}
+        #  for Epics PV source
+        self.epicspvshapes = '{}'
         #: (:obj:`str`) JSON dictionary with {label: doocs property}
         #  for DOOCS Property source
         self.doocsprops = '{}'
@@ -166,8 +182,12 @@ class Settings(object):
         self.storegeometry = False
         #: (:obj:`bool`) fetch geometry from source
         self.geometryfromsource = False
+        #: (:obj:`bool`) crosshair locker switched on
+        self.crosshairlocker = True
         #: (:obj:`str`) json list with roi colors
         self.roiscolors = "[]"
+        #: (:obj:`str`) float type for pixel intensity
+        self.floattype = "float"
 
         #: (:obj:`str`) json list with filters
         self.filters = "[]"
@@ -287,6 +307,11 @@ class Settings(object):
         qstval = str(settings.value("Configuration/SecAutoPort", type=str))
         if qstval.lower() == "false":
             self.secautoport = False
+        qstval = str(settings.value("Configuration/FloatType", type=str))
+        if qstval.lower() in ["float", "float32", "float64"]:
+            self.floattype = qstval.lower()
+        else:
+            self.floattype = "float"
         qstval = str(settings.value(
             "Configuration/ShowSubtraction", type=str))
         if qstval.lower() == "false":
@@ -336,6 +361,12 @@ class Settings(object):
         qstval = str(settings.value("Configuration/ShowStatistics", type=str))
         if qstval.lower() == "false":
             self.showstats = False
+        qstval = str(settings.value("Configuration/ShowImageSteps", type=str))
+        if qstval.lower() == "false":
+            self.showsteps = False
+        qstval = str(settings.value("Configuration/CrossHairLocker", type=str))
+        if qstval.lower() == "false":
+            self.crosshairlocker = False
         qstval = str(settings.value(
             "Configuration/CalculateVariance", type=str))
         if qstval.lower() == "true":
@@ -437,6 +468,12 @@ class Settings(object):
         except Exception:
             pass
 
+        try:
+            self.toolpollinginterval = float(
+                settings.value("Configuration/ToolPollingInterval", type=str))
+        except Exception:
+            pass
+
         qstval = str(
             settings.value("Configuration/InterruptOnError", type=str))
         if qstval.lower() == "false":
@@ -467,13 +504,13 @@ class Settings(object):
             settings.value(
                 "Configuration/ImageSources", type=str)
         if qstval:
-            self.imagesources = qstval
+            self.imagesources = str(qstval)
 
         qstval = \
             settings.value(
                 "Configuration/ToolWidgets", type=str)
         if qstval:
-            self.toolwidgets = qstval
+            self.toolwidgets = str(qstval)
 
         qstval = \
             settings.value(
@@ -511,6 +548,25 @@ class Settings(object):
         if qstval:
             self.tangoattrs = qstval
 
+        qstval = str(
+            settings.value("Configuration/TangoDetectorAttributes", type=str))
+        if qstval:
+            self.tangodetattrs = qstval
+
+        qstval = str(
+            settings.value("Configuration/TineProperties", type=str))
+        if qstval:
+            self.tineprops = qstval
+
+        qstval = str(
+            settings.value("Configuration/EpicsPVNames", type=str))
+        if qstval:
+            self.epicspvnames = qstval
+        qstval = str(
+            settings.value("Configuration/EpicsPVShapes", type=str))
+        if qstval:
+            self.epicspvshapes = qstval
+
         qstval = str(
             settings.value("Configuration/DOOCSProperties", type=str))
         if qstval:
@@ -653,6 +709,12 @@ class Settings(object):
         settings.setValue(
             "Configuration/ShowStatistics",
             self.showstats)
+        settings.setValue(
+            "Configuration/ShowImageSteps",
+            self.showsteps)
+        settings.setValue(
+            "Configuration/CrossHairLocker",
+            self.crosshairlocker)
         settings.setValue(
             "Configuration/CalculateVariance",
             self.calcvariance)
@@ -662,9 +724,15 @@ class Settings(object):
         settings.setValue(
             "Configuration/ToolRefreshTime",
             self.toolrefreshtime)
+        settings.setValue(
+            "Configuration/ToolPollingInterval",
+            self.toolpollinginterval)
         settings.setValue(
             "Configuration/SecPort",
             self.secport)
+        settings.setValue(
+            "Configuration/FloatType",
+            self.floattype)
         settings.setValue(
             "Configuration/HidraDataPort",
             self.hidraport)
@@ -743,6 +811,18 @@ class Settings(object):
         settings.setValue(
             "Configuration/TangoAttributes",
             self.tangoattrs)
+        settings.setValue(
+            "Configuration/TangoDetectorAttributes",
+            self.tangodetattrs)
+        settings.setValue(
+            "Configuration/TineProperties",
+            self.tineprops)
+        settings.setValue(
+            "Configuration/EpicsPVNames",
+            self.epicspvnames)
+        settings.setValue(
+            "Configuration/EpicsPVShapes",
+            self.epicspvshapes)
         settings.setValue(
             "Configuration/DOOCSProperties",
             self.doocsprops)
