@@ -29,6 +29,7 @@ from .qtuic import uic
 from pyqtgraph import QtCore, QtGui
 import os
 import json
+from .sardanaUtils import debugmethod
 
 from . import sourceWidget as swgm
 
@@ -64,7 +65,8 @@ class SourceForm(QtGui.QWidget):
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) push button enabled signal
     buttonEnabled = QtCore.pyqtSignal(bool, int)
 
-    def __init__(self, parent=None, sourceid=0):
+    @debugmethod
+    def __init__(self, parent=None, sourceid=0, usersourcenames=None):
         """ constructor
 
         :param parent: parent object
@@ -73,6 +75,8 @@ class SourceForm(QtGui.QWidget):
         :type expertmode: :obj:`bool`
         :param sourceid: source id
         :type sourceid: :obj:`int`
+        :param usersourcenames: user source names
+        :type  usersourcenames: :obj:`list` < :obj:`str` >
         """
         QtGui.QWidget.__init__(self, parent)
 
@@ -84,10 +88,12 @@ class SourceForm(QtGui.QWidget):
         self.__currentSource = None
 
         #:  (:obj:`str`) default datasource
-        self.__defaultsource = "Hidra"
+        self.__defaultsource = ""
 
         #: (:obj:`list` < :obj:`str` > ) source names
         self.__sourcenames = []
+        #: (:obj:`list` < :obj:`str` > ) user source names
+        self.__usersourcenames = usersourcenames or []
         #: (:obj:`dict` < :obj:`str`,
         #:      :class:`lavuelib.sourceWidget.SourceBaseWidget` >)
         #:           source names
@@ -115,7 +121,11 @@ class SourceForm(QtGui.QWidget):
 
         self._ui = _sformclass()
         self._ui.setupUi(self)
+        if QtGui.QIcon.hasThemeIcon("video-display"):
+            icon = QtGui.QIcon.fromTheme("video-display")
+            self._ui.pushButton.setIcon(icon)
 
+    @debugmethod
     def init(self):
         """ initialize widget
         """
@@ -123,6 +133,7 @@ class SourceForm(QtGui.QWidget):
             self.onSourceChanged)
         self.onSourceChanged()
 
+    @debugmethod
     def disconnectWidget(self):
         """ disconnect widget
         """
@@ -132,11 +143,15 @@ class SourceForm(QtGui.QWidget):
         self._ui.cStatusLineEdit.setText("Disconnected")
         if not self.__sourceid:
             self._ui.pushButton.setText("&Start")
+            if QtGui.QIcon.hasThemeIcon("video-display"):
+                icon = QtGui.QIcon.fromTheme("video-display")
+                self._ui.pushButton.setIcon(icon)
         self.__connected = False
         self._ui.sourceTypeComboBox.setEnabled(True)
         if self.__currentSource is not None:
             self.__currentSource.disconnectWidget()
 
+    @debugmethod
     def connectWidget(self):
         """ connect widget
         """
@@ -144,6 +159,7 @@ class SourceForm(QtGui.QWidget):
         if self.__currentSource is not None:
             self.__currentSource.connectWidget()
 
+    @debugmethod
     def currentDataSource(self):
         """ current data source
 
@@ -153,6 +169,7 @@ class SourceForm(QtGui.QWidget):
         if self.__currentSource is not None:
             return self.__currentSource.datasource
 
+    @debugmethod
     def currentDataSourceName(self):
         """ current data source name
 
@@ -161,6 +178,16 @@ class SourceForm(QtGui.QWidget):
         """
         return self.__currentSource.name
 
+    @debugmethod
+    def currentDataSourceAlias(self):
+        """ current data source name
+
+        :returns: current datasource class name alias
+        :rtype: :obj:`str`
+        """
+        return self.__currentSource.alias
+
+    @debugmethod
     def gridLayout(self):
         """ provide grid layout
 
@@ -169,6 +196,7 @@ class SourceForm(QtGui.QWidget):
         """
         return self._ui.formGridLayout
 
+    @debugmethod
     def pushButtonEnabled(self):
         """ provide status of push button
 
@@ -177,6 +205,7 @@ class SourceForm(QtGui.QWidget):
         """
         return self._ui.pushButton.isEnabled()
 
+    @debugmethod
     def removeCommonWidgets(self):
         """ remove common widgets
         """
@@ -187,6 +216,7 @@ class SourceForm(QtGui.QWidget):
         layout.removeWidget(self._ui.translationLineEdit)
         layout.removeWidget(self._ui.pushButton)
 
+    @debugmethod
     def addCommonWidgets(self, sln):
         """ add common widgets after given row in the grid layout
 
@@ -208,6 +238,7 @@ class SourceForm(QtGui.QWidget):
             self.emitTranslationChanged)
         self._ui.sourceTypeComboBox.setCurrentIndex(0)
 
+    @debugmethod
     def showItem(self, trans):
         """ show items of the widget
 
@@ -221,6 +252,7 @@ class SourceForm(QtGui.QWidget):
             self._ui.translationLineEdit.hide()
             self._ui.translationLabel.hide()
 
+    @debugmethod
     def addWidgets(self, st, expertmode):
         """ add widgets
 
@@ -233,7 +265,8 @@ class SourceForm(QtGui.QWidget):
         swg = getattr(swgm, st)()
         swg.expertmode = expertmode
         self.__sourcewidgets[swg.name] = swg
-        self.__sourcenames.append(swg.name)
+        if swg.name not in self.__sourcenames:
+            self.__sourcenames.append(swg.name)
         self._ui.sourceTypeComboBox.addItem(swg.name)
         widgets = zip(swg.widgets[0::2], swg.widgets[1::2])
         for wg1, wg2 in widgets:
@@ -244,6 +277,7 @@ class SourceForm(QtGui.QWidget):
         swg.updateComboBox()
         return len(self.__subwidgets)
 
+    @debugmethod
     def sourceStatus(self):
         """ source status
 
@@ -252,6 +286,7 @@ class SourceForm(QtGui.QWidget):
         """
         return self._ui.sourceTypeComboBox.currentIndex() + 1
 
+    @debugmethod
     def updateLayout(self):
         """ update source layout
         """
@@ -271,6 +306,7 @@ class SourceForm(QtGui.QWidget):
         if mst:
             mst.updateButton()
 
+    @debugmethod
     def updateSourceComboBox(self, sourcenames, name=None):
         """ set source by changing combobox
 
@@ -279,7 +315,7 @@ class SourceForm(QtGui.QWidget):
         :param index: combobox index
         :type index: :obj:`int`
         """
-
+        self.__usersourcenames = sourcenames
         self._ui.sourceTypeComboBox.currentIndexChanged.disconnect(
             self.onSourceChanged)
         if sourcenames and name and name not in sourcenames:
@@ -297,10 +333,13 @@ class SourceForm(QtGui.QWidget):
         if index == -1:
             index = 0
         self._ui.sourceTypeComboBox.setCurrentIndex(index)
+
+        self.onSourceChanged()
         self.updateLayout()
         self._ui.sourceTypeComboBox.currentIndexChanged.connect(
            self.onSourceChanged)
 
+    @debugmethod
     def setSource(self, name=None, disconnect=True):
         """ set source with the given name
 
@@ -339,6 +378,7 @@ class SourceForm(QtGui.QWidget):
         self.updateMetaData(disconnect=disconnect)
         self.emitSourceChanged()
 
+    @debugmethod
     def label(self):
         """ return a label of the current detector
 
@@ -347,6 +387,7 @@ class SourceForm(QtGui.QWidget):
         """
         return self.__currentSource.label()
 
+    @debugmethod
     def updateMetaData(self, **kargs):
         """ update source input parameters
 
@@ -356,6 +397,7 @@ class SourceForm(QtGui.QWidget):
         for wg in self.__sourcewidgets.values():
             wg.updateMetaData(**kargs)
 
+    @debugmethod
     def setSourceComboBoxByName(self, name):
         """ set source by changing combobox by name
 
@@ -366,12 +408,14 @@ class SourceForm(QtGui.QWidget):
         if index != -1:
             self._ui.sourceTypeComboBox.setCurrentIndex(index)
 
+    @debugmethod
     def emitSourceChanged(self):
         """ emits sourceChanged signal
         """
         status = self._ui.sourceTypeComboBox.currentIndex() + 1
         self.sourceChanged.emit(status)
 
+    @debugmethod
     @QtCore.pyqtSlot(str, str)
     def _emitAddIconClicked(self, name, value):
         """ emits addIconClicked signal
@@ -383,6 +427,7 @@ class SourceForm(QtGui.QWidget):
         """
         self.addIconClicked.emit(name, value)
 
+    @debugmethod
     @QtCore.pyqtSlot(str, str)
     def _emitRemoveIconClicked(self, name, label):
         """ emits addIconClicked signal
@@ -394,12 +439,14 @@ class SourceForm(QtGui.QWidget):
         """
         self.removeIconClicked.emit(name, label)
 
+    @debugmethod
     @QtCore.pyqtSlot()
     def _emitSourceLabelChanged(self):
         """ emits sourceLabelChanged signal
         """
         self.sourceLabelChanged.emit()
 
+    @debugmethod
     @QtCore.pyqtSlot(int)
     def _emitSourceStateChanged(self, status):
         """ emits sourceStateChanged signal
@@ -412,6 +459,7 @@ class SourceForm(QtGui.QWidget):
         else:
             self.sourceStateChanged.emit(status, self.__sourceid)
 
+    @debugmethod
     @QtCore.pyqtSlot(bool)
     def updateButton(self, status):
         """ update slot for source button
@@ -421,6 +469,7 @@ class SourceForm(QtGui.QWidget):
         """
         self._ui.pushButton.setEnabled(status)
 
+    @debugmethod
     def isConnected(self):
         """ is datasource source connected
 
@@ -429,12 +478,14 @@ class SourceForm(QtGui.QWidget):
         """
         return self.__connected
 
+    @debugmethod
     @QtCore.pyqtSlot()
     def toggleServerConnection(self):
         """ toggles server connection
         """
         self.pushButtonClicked.emit()
 
+    @debugmethod
     @QtCore.pyqtSlot(str)
     def emitTranslationChanged(self, trans):
         """ emit translationChanged
@@ -444,6 +495,7 @@ class SourceForm(QtGui.QWidget):
         """
         self.translationChanged.emit(trans, self.__sourceid)
 
+    @debugmethod
     @QtCore.pyqtSlot(bool)
     def emitButtonEnabled(self, status):
         """ emit buttonEnabled
@@ -453,6 +505,7 @@ class SourceForm(QtGui.QWidget):
         """
         self.buttonEnabled.emit(status, self.__sourceid)
 
+    @debugmethod
     def setErrorStatus(self, status=""):
         """ set error status
 
@@ -472,6 +525,7 @@ class SourceForm(QtGui.QWidget):
                 "background-color: green;")
         self.__errorstatus = status
 
+    @debugmethod
     def connectSuccess(self, port=None):
         """ set connection status on and display connection status
 
@@ -495,15 +549,26 @@ class SourceForm(QtGui.QWidget):
 
         if not self.__sourceid:
             self._ui.pushButton.setText("&Stop")
+            if QtGui.QIcon.hasThemeIcon("process-stop"):
+                icon = QtGui.QIcon.fromTheme("process-stop")
+                self._ui.pushButton.setIcon(icon)
         if self.__currentSource is not None:
             self.__currentSource.connectWidget()
 
+    @debugmethod
     @QtCore.pyqtSlot()
     def onSourceChanged(self):
         """ update current source widgets
         """
-        self.setSource(str(self._ui.sourceTypeComboBox.currentText()))
+        name = str(self._ui.sourceTypeComboBox.currentText())
+        if self.__usersourcenames:
+            us = [sr for sr in self.__usersourcenames
+                  if sr in self.__sourcenames]
+            if name not in us and us:
+                name = us[0]
+        self.setSource(name)
 
+    @debugmethod
     def connectFailure(self):
         """ set connection status off and display connection status
         """
@@ -514,10 +579,14 @@ class SourceForm(QtGui.QWidget):
         self._ui.sourceTypeComboBox.setEnabled(True)
         if not self.__sourceid:
             self._ui.pushButton.setText("&Start")
+            if QtGui.QIcon.hasThemeIcon("video-display"):
+                icon = QtGui.QIcon.fromTheme("video-display")
+                self._ui.pushButton.setIcon(icon)
         if self.__currentSource is not None:
             self.__currentSource.disconnectWidget()
         # self.pushButton.setText("Retry connect")
 
+    @debugmethod
     def configure(self, configuration):
         """ set configuration for the current image source
 
@@ -528,6 +597,7 @@ class SourceForm(QtGui.QWidget):
         if self.__currentSource is not None:
             self.__currentSource.configure(configuration)
 
+    @debugmethod
     def setTranslation(self, trans):
         """ stores translation of the given source
 
@@ -536,6 +606,7 @@ class SourceForm(QtGui.QWidget):
         """
         self._ui.translationLineEdit.setText(trans)
 
+    @debugmethod
     def configuration(self):
         """ provides configuration for the current image source
 
@@ -545,6 +616,7 @@ class SourceForm(QtGui.QWidget):
         if self.__currentSource is not None:
             return self.__currentSource.configuration()
 
+    @debugmethod
     def start(self):
         """ starts viewing if pushButton enable
         """
@@ -573,6 +645,7 @@ class SourceTabWidget(QtGui.QTabWidget):
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) translation changed signal
     translationChanged = QtCore.pyqtSignal(str, int)
 
+    @debugmethod
     def __init__(self, parent=None, sourcetypes=None, expertmode=False,
                  nrsources=1):
         """ constructor
@@ -601,12 +674,14 @@ class SourceTabWidget(QtGui.QTabWidget):
         #: (:obj:`list` < :obj:`str` > ) source class names
         self.__types = sourcetypes or []
         #:  (:obj:`str`) default datasource
-        self.__defaultsource = "Hidra"
+        self.__defaultsource = ""
         #:  (:obj:`bool`) expert mode flag
         self.__expertmode = expertmode
 
         #: (:obj:`list` < :obj:`str` > ) source names
         self.__sourcenames = []
+        #: (:obj:`list` < :obj:`str` > ) user source names
+        self.__usersourcenames = []
         # (:obj:`str`) error status
         self.__errorstatus = ""
 
@@ -631,6 +706,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         for st in self.__sourcetabs:
             st.init()
 
+    @debugmethod
     def addTab(self, widget, title):
         """ add tab widget
 
@@ -650,6 +726,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         cb.stateChanged.connect(
             lambda state: self.__updateCheckBoxState(cb, state))
 
+    @debugmethod
     def removeTab(self, sid):
         """ remove tab widget
 
@@ -661,6 +738,7 @@ class SourceTabWidget(QtGui.QTabWidget):
             self.__tabcheckboxstates.pop(sid)
         QtGui.QTabWidget.removeTab(self, sid)
 
+    @debugmethod
     def isChecked(self, sid):
         """ check if tab is active
 
@@ -671,6 +749,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         return self.tabBar().tabButton(sid, QtGui.QTabBar.RightSide).state()
 
+    @debugmethod
     def setCheckState(self, sid, state):
         """ set check status
 
@@ -682,6 +761,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         self.tabBar().tabButton(
             sid, QtGui.QTabBar.RightSide).setCheckState(state)
 
+    @debugmethod
     def __updateCheckBoxState(self, cb, state):
         """ update checkbox state
 
@@ -696,6 +776,7 @@ class SourceTabWidget(QtGui.QTabWidget):
             for sid in range(len(self.__tabcheckboxstates)):
                 self.setCheckState(sid, 2)
 
+    @debugmethod
     def tabCheckBoxStates(self):
         """ provides checkbox states
 
@@ -704,6 +785,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         return tuple(self.__tabcheckboxstates)
 
+    @debugmethod
     def currentDataSources(self):
         """ current data source
 
@@ -713,6 +795,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         return [st.currentDataSource()
                 for st in self.__sourcetabs][:self.count()]
 
+    @debugmethod
     def currentDataSourceNames(self):
         """ current data source name
 
@@ -722,6 +805,17 @@ class SourceTabWidget(QtGui.QTabWidget):
         return [st.currentDataSourceName()
                 for st in self.__sourcetabs][:self.count()]
 
+    @debugmethod
+    def currentDataSourceAlias(self):
+        """ current data source name alias
+
+        :returns: current datasource class name alias
+        :rtype: :obj:`str`
+        """
+        return [st.currentDataSourceAlias()
+                for st in self.__sourcetabs][:self.count()]
+
+    @debugmethod
     def __addSourceWidgets(self, wg=None):
         """ add source subwidgets into grid layout
 
@@ -734,7 +828,8 @@ class SourceTabWidget(QtGui.QTabWidget):
         for st in self.__types:
             sln = wg.addWidgets(st, self.__expertmode)
             swg = getattr(swgm, st)
-            self.__sourcenames.append(swg.name)
+            if swg.name not in self.__sourcenames:
+                self.__sourcenames.append(swg.name)
 
         wg.addCommonWidgets(sln)
         wg.buttonEnabled.connect(self.updateButton)
@@ -748,6 +843,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         self.__sourcetabs.append(wg)
         self.__buttonstatus.append(False)
 
+    @debugmethod
     def setNumberOfSources(self, nrsources):
         """ set a number of image sources
 
@@ -765,7 +861,8 @@ class SourceTabWidget(QtGui.QTabWidget):
 
                 self.addTab(self.__sourcetabs[i], str(i + 1))
             for i in range(len(self.__sourcetabs), nrsources):
-                sf = SourceForm(self, sourceid=i)
+                sf = SourceForm(self, sourceid=i,
+                                usersourcenames=self.__usersourcenames)
                 self.__addSourceWidgets(sf)
                 sf.init()
                 self.addTab(sf, str(i + 1))
@@ -783,6 +880,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         self.showItem(nrsources > 1)
         self.emitSourceChanged()
 
+    @debugmethod
     def setSourceComboBoxByName(self, sid, name):
         """ set source by changing combobox by name
 
@@ -794,6 +892,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         if len(self.__sourcetabs) > sid:
             self.__sourcetabs[sid].setSourceComboBoxByName(name)
 
+    @debugmethod
     def updateSourceComboBox(self, sourcenames, names=None):
         """ set source by changing combobox
 
@@ -802,22 +901,28 @@ class SourceTabWidget(QtGui.QTabWidget):
         :param sourcenames: source names to set
         :type names: :obj:`list` < :obj:`str` >
         """
+        self.__usersourcenames = sourcenames
         for i, st in enumerate(self.__sourcetabs):
             if names and len(names) > i:
                 st.updateSourceComboBox(sourcenames, names[i])
+            else:
+                st.updateSourceComboBox(sourcenames)
 
+    @debugmethod
     @QtCore.pyqtSlot()
     def onSourceChanged(self):
         """ update current source widgets
         """
         self.__setSource(str(self._ui.sourceTypeComboBox.currentText()))
 
+    @debugmethod
     def updateLayout(self):
         """ update source layout
         """
         for st in self.__sourcetabs:
             st.updateLayout()
 
+    @debugmethod
     def __setSource(self, name=None, disconnect=True):
         """ set source with the given name
 
@@ -829,7 +934,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         for st in self.__sourcetabs:
             st.setSource(name, disconnect)
 
-    @QtCore.pyqtSlot(int)
+    @debugmethod
     @QtCore.pyqtSlot()
     def emitSourceChanged(self):
         """ emits sourceChanged signal
@@ -838,6 +943,7 @@ class SourceTabWidget(QtGui.QTabWidget):
                              for st in self.__sourcetabs][:self.count()])
         self.sourceChanged.emit(status)
 
+    @debugmethod
     @QtCore.pyqtSlot(str, str)
     def _emitAddIconClicked(self, name, value):
         """ emits addIconClicked signal
@@ -849,6 +955,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         self.addIconClicked.emit(name, value)
 
+    @debugmethod
     @QtCore.pyqtSlot(str, str)
     def _emitRemoveIconClicked(self, name, label):
         """ emits addIconClicked signal
@@ -860,6 +967,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         self.removeIconClicked.emit(name, label)
 
+    @debugmethod
     @QtCore.pyqtSlot()
     def _emitSourceLabelChanged(self):
         """ emits sourceLabelChanged signal with the given name
@@ -868,6 +976,7 @@ class SourceTabWidget(QtGui.QTabWidget):
                            for st in self.__sourcetabs][:self.count()])
         self.sourceLabelChanged.emit(status)
 
+    @debugmethod
     @QtCore.pyqtSlot(int, int)
     def _emitSourceStateChanged(self, status, sid):
         """ emits sourceStateChanged signal with the current source id
@@ -885,6 +994,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         else:
             self.sourceStateChanged.emit(status, sid)
 
+    @debugmethod
     @QtCore.pyqtSlot(str, int)
     def _emitTranslationChanged(self, trans, sid):
         """ emits sourceStateChanged signal with the current source id
@@ -896,9 +1006,10 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         self.translationChanged.emit(trans, sid)
 
+    @debugmethod
     @QtCore.pyqtSlot(bool, int)
     def updateButton(self, status, sid):
-        """ update slot for test source
+        """ update slot for image source
 
         :param status: button status
         :type status: :obj:`bool`
@@ -907,11 +1018,13 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         while len(self.__buttonstatus) <= sid:
             self.__buttonstatus.append(False)
+            self.__sourcetabs[-1].updateLayout()
         self.__buttonstatus[sid] = status
         lstatus = self.__buttonstatus[:self.count()]
         fstatus = sum(lstatus) == len(lstatus)
         self.__sourcetabs[0].updateButton(fstatus)
 
+    @debugmethod
     def updateMetaData(self, **kargs):
         """ update source input parameters
 
@@ -921,6 +1034,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         for st in self.__sourcetabs:
             st.updateMetaData(**kargs)
 
+    @debugmethod
     def updateSourceMetaData(self, sid, **kargs):
         """ update source input parameters
 
@@ -932,6 +1046,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         if len(self.__sourcetabs) > sid:
             self.__sourcetabs[sid].updateMetaData(**kargs)
 
+    @debugmethod
     def isConnected(self):
         """ is datasource source connected
 
@@ -940,6 +1055,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         """
         return self.__connected
 
+    @debugmethod
     @QtCore.pyqtSlot()
     def toggleServerConnection(self):
         """ toggles server connection
@@ -959,6 +1075,7 @@ class SourceTabWidget(QtGui.QTabWidget):
                  for st in self.__sourcetabs][:self.count()])
             self.sourceConnected.emit(status)
 
+    @debugmethod
     def setErrorStatus(self, status=""):
         """ set error status
 
@@ -969,6 +1086,7 @@ class SourceTabWidget(QtGui.QTabWidget):
             st.setErrorStatus(status)
         self.__errorstatus = status
 
+    @debugmethod
     def connectSuccess(self, port=None):
         """ set connection status on and display connection status
 
@@ -979,6 +1097,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         for st in self.__sourcetabs:
             st.connectSuccess(port)
 
+    @debugmethod
     def connectFailure(self):
         """ set connection status off and display connection status
         """
@@ -987,6 +1106,7 @@ class SourceTabWidget(QtGui.QTabWidget):
             self.sourceStateChanged.emit(0, i)
             st.connectFailure()
 
+    @debugmethod
     def configure(self, sid, configuration):
         """ set configuration for the current image source
 
@@ -999,15 +1119,17 @@ class SourceTabWidget(QtGui.QTabWidget):
         if len(self.__sourcetabs) > sid:
             self.__sourcetabs[sid].configure(configuration)
 
+    @debugmethod
     def configuration(self):
         """ provides configuration for the current image source
 
         :return: configuration string
         :rtype configuration: :obj:`str`
         """
-        return [st.configuration()
+        return [st.configuration() or ""
                 for st in self.__sourcetabs][:self.count()]
 
+    @debugmethod
     def setTranslation(self, trans, sid):
         """ stores translation of the given source
 
@@ -1019,6 +1141,7 @@ class SourceTabWidget(QtGui.QTabWidget):
         if len(self.__sourcetabs) > sid:
             self.__sourcetabs[sid].setTranslation(trans)
 
+    @debugmethod
     def showItem(self, trans):
         """ show items of the widget
 
@@ -1033,6 +1156,7 @@ class SourceTabWidget(QtGui.QTabWidget):
             else:
                 cb.hide()
 
+    @debugmethod
     def start(self):
         """ starts viewing if pushButton enable
         """
